==> openshift-model-6.5.1-sources.jar: io/fabric8/openshift/api/model/TemplateInstanceObjectFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TemplateInstanceObjectFluentImpl<A extends TemplateInstanceObjectFluent<A>> extends BaseFluent<A> implements TemplateInstanceObjectFluent<A>{
  public TemplateInstanceObjectFluentImpl() {
  }
  public TemplateInstanceObjectFluentImpl(TemplateInstanceObject instance) {
    this.withRef(instance.getRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ObjectReferenceBuilder ref;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getRef() {
    return this.ref!=null ?this.ref.build():null;
  }
  public ObjectReference buildRef() {
    return this.ref!=null ?this.ref.build():null;
  }
  public A withRef(ObjectReference ref) {
    _visitables.get("ref").remove(this.ref);
    if (ref!=null){ this.ref= new ObjectReferenceBuilder(ref); _visitables.get("ref").add(this.ref);} else { this.ref = null; _visitables.get("ref").remove(this.ref); } return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  public TemplateInstanceObjectFluent.RefNested<A> withNewRef() {
    return new TemplateInstanceObjectFluentImpl.RefNestedImpl();
  }
  public TemplateInstanceObjectFluent.RefNested<A> withNewRefLike(ObjectReference item) {
    return new TemplateInstanceObjectFluentImpl.RefNestedImpl(item);
  }
  public TemplateInstanceObjectFluent.RefNested<A> editRef() {
    return withNewRefLike(getRef());
  }
  public TemplateInstanceObjectFluent.RefNested<A> editOrNewRef() {
    return withNewRefLike(getRef() != null ? getRef(): new ObjectReferenceBuilder().build());
  }
  public TemplateInstanceObjectFluent.RefNested<A> editOrNewRefLike(ObjectReference item) {
    return withNewRefLike(getRef() != null ? getRef(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TemplateInstanceObjectFluentImpl that = (TemplateInstanceObjectFluentImpl) o;
    if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ref,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class RefNestedImpl<N> extends ObjectReferenceFluentImpl<TemplateInstanceObjectFluent.RefNested<N>> implements TemplateInstanceObjectFluent.RefNested<N>,Nested<N>{
    RefNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    RefNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) TemplateInstanceObjectFluentImpl.this.withRef(builder.build());
    }
    public N endRef() {
      return and();
    }
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/TemplateInstanceObjectFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TemplateInstanceObjectFluentImpl<A extends TemplateInstanceObjectFluent<A>> extends BaseFluent<A> implements TemplateInstanceObjectFluent<A>{
  public TemplateInstanceObjectFluentImpl() {
  }
  public TemplateInstanceObjectFluentImpl(TemplateInstanceObject instance) {
    if (instance != null) {
      this.withRef(instance.getRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ObjectReferenceBuilder ref;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getRef() {
    return this.ref!=null ?this.ref.build():null;
  }
  public ObjectReference buildRef() {
    return this.ref!=null ?this.ref.build():null;
  }
  public A withRef(ObjectReference ref) {
    _visitables.get("ref").remove(this.ref);
    if (ref!=null){ this.ref= new ObjectReferenceBuilder(ref); _visitables.get("ref").add(this.ref);} else { this.ref = null; _visitables.get("ref").remove(this.ref); } return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  public TemplateInstanceObjectFluentImpl.RefNested<A> withNewRef() {
    return new TemplateInstanceObjectFluentImpl.RefNestedImpl();
  }
  public TemplateInstanceObjectFluentImpl.RefNested<A> withNewRefLike(ObjectReference item) {
    return new TemplateInstanceObjectFluentImpl.RefNestedImpl(item);
  }
  public TemplateInstanceObjectFluentImpl.RefNested<A> editRef() {
    return withNewRefLike(getRef());
  }
  public TemplateInstanceObjectFluentImpl.RefNested<A> editOrNewRef() {
    return withNewRefLike(getRef() != null ? getRef(): new ObjectReferenceBuilder().build());
  }
  public TemplateInstanceObjectFluentImpl.RefNested<A> editOrNewRefLike(ObjectReference item) {
    return withNewRefLike(getRef() != null ? getRef(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TemplateInstanceObjectFluentImpl that = (TemplateInstanceObjectFluentImpl) o;
    if (!java.util.Objects.equals(ref, that.ref)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ref,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class RefNestedImpl<N> extends ObjectReferenceFluentImpl<TemplateInstanceObjectFluentImpl.RefNested<N>> implements TemplateInstanceObjectFluentImpl.RefNested<N>,Nested<N>{
    RefNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    RefNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) TemplateInstanceObjectFluentImpl.this.withRef(builder.build());
    }
    public N endRef() {
      return and();
    }
    
  }
  
}
